@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -80,24 +79,18 @@ that can be used to attach Bokeh properties to Bokeh models.
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
 
-
 # Standard library imports
 from copy import copy
 
-# External imports
-from six import string_types
-
 # Bokeh imports
-from .wrappers import PropertyValueContainer
+from .wrappers import PropertyValueColumnData, PropertyValueContainer
 
 #-----------------------------------------------------------------------------
 # Globals and constants
@@ -450,7 +443,7 @@ class BasicPropertyDescriptor(PropertyDescriptor):
             property (Property) : A basic property to create a descriptor for
 
         '''
-        super(BasicPropertyDescriptor, self).__init__(name)
+        super().__init__(name)
         self.property = property
         self.__doc__ = self.property.__doc__
 
@@ -614,7 +607,7 @@ class BasicPropertyDescriptor(PropertyDescriptor):
             None
 
         '''
-        return super(BasicPropertyDescriptor, self).set_from_json(obj,
+        return super().set_from_json(obj,
                                                         self.property.from_json(json, models),
                                                         models, setter)
 
@@ -916,6 +909,14 @@ class BasicPropertyDescriptor(PropertyDescriptor):
             obj.trigger(self.name, old, value, hint, setter)
 
 
+_CDS_SET_FROM_CDS_ERROR = """
+ColumnDataSource.data properties may only be set from plain Python dicts,
+not other ColumnDataSource.data values.
+
+If you need to copy set from one CDS to another, make a shallow copy by
+calling dict: s1.data = dict(s2.data)
+"""
+
 class ColumnDataPropertyDescriptor(BasicPropertyDescriptor):
     ''' A ``PropertyDescriptor`` specialized to handling ``ColumnData`` properties.
 
@@ -964,6 +965,9 @@ class ColumnDataPropertyDescriptor(BasicPropertyDescriptor):
         if self.property._readonly:
             raise RuntimeError("%s.%s is a readonly property" % (obj.__class__.__name__, self.name))
 
+        if isinstance(value, PropertyValueColumnData):
+            raise ValueError(_CDS_SET_FROM_CDS_ERROR)
+
         from ...document.events import ColumnDataChangedEvent
 
         if obj.document:
@@ -1022,11 +1026,11 @@ class DataSpecPropertyDescriptor(BasicPropertyDescriptor):
                     if 'value' in json:
                         json = json['value']
                 except ValueError:
-                    if isinstance(old, string_types) and 'field' in json:
+                    if isinstance(old, str) and 'field' in json:
                         json = json['field']
                 # leave it as a dict if 'old' was a dict
 
-        super(DataSpecPropertyDescriptor, self).set_from_json(obj, json, models, setter)
+        super().set_from_json(obj, json, models, setter)
 
 class UnitsSpecPropertyDescriptor(DataSpecPropertyDescriptor):
     ''' A ``PropertyDecscriptor`` for Bokeh |UnitsSpec| properties that contribute
@@ -1048,7 +1052,7 @@ class UnitsSpecPropertyDescriptor(DataSpecPropertyDescriptor):
                 An associated property to hold units information
 
         '''
-        super(UnitsSpecPropertyDescriptor, self).__init__(name, property)
+        super().__init__(name, property)
         self.units_prop = units_property
 
     def __set__(self, obj, value, setter=None):
@@ -1087,7 +1091,7 @@ class UnitsSpecPropertyDescriptor(DataSpecPropertyDescriptor):
 
         '''
         value = self._extract_units(obj, value)
-        super(UnitsSpecPropertyDescriptor, self).__set__(obj, value, setter)
+        super().__set__(obj, value, setter)
 
     def set_from_json(self, obj, json, models=None, setter=None):
         ''' Sets the value of this property from a JSON value.
@@ -1124,7 +1128,7 @@ class UnitsSpecPropertyDescriptor(DataSpecPropertyDescriptor):
 
         '''
         json = self._extract_units(obj, json)
-        super(UnitsSpecPropertyDescriptor, self).set_from_json(obj, json, models, setter)
+        super().set_from_json(obj, json, models, setter)
 
     def _extract_units(self, obj, value):
         ''' Internal helper for dealing with units associated units properties
