@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -11,9 +11,7 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
@@ -22,14 +20,12 @@ log = logging.getLogger(__name__)
 
 # Standard library imports
 import json
-from warnings import warn
 from uuid import uuid4
-
-# External imports
+from warnings import warn
 
 # Bokeh imports
-from .state import curstate
 from ..util.serialization import make_id
+from .state import curstate
 
 #-----------------------------------------------------------------------------
 # Globals and constants
@@ -188,7 +184,7 @@ def install_notebook_hook(notebook_type, load, show_doc, show_app, overwrite=Fal
         raise RuntimeError("hook for notebook type %r already exists" % notebook_type)
     _HOOKS[notebook_type] = dict(load=load, doc=show_doc, app=show_app)
 
-def push_notebook(document=None, state=None, handle=None):
+def push_notebook(*, document=None, state=None, handle=None):
     ''' Update Bokeh plots in a Jupyter notebook output cells with new data
     or property values.
 
@@ -265,7 +261,7 @@ def push_notebook(document=None, state=None, handle=None):
         return
 
     handle.doc._held_events = []
-    msg = Protocol("1.0").create("PATCH-DOC", events)
+    msg = Protocol().create("PATCH-DOC", events)
 
     handle.comms.send(msg.header_json)
     handle.comms.send(msg.metadata_json)
@@ -374,15 +370,15 @@ def load_notebook(resources=None, verbose=False, hide_banner=False, load_timeout
 
     from .. import __version__
     from ..core.templates import NOTEBOOK_LOAD
+    from ..resources import Resources
+    from ..settings import settings
     from ..util.serialization import make_id
-    from ..resources import CDN
-    from ..util.compiler import bundle_all_models
+    from ..embed.bundle import bundle_for_objs_and_resources
 
     if resources is None:
-        resources = CDN
+        resources = Resources(mode=settings.resources())
 
     if not hide_banner:
-
         if resources.mode == 'inline':
             js_info = 'inline'
             css_info = 'inline'
@@ -410,16 +406,16 @@ def load_notebook(resources=None, verbose=False, hide_banner=False, load_timeout
 
     _NOTEBOOK_LOADED = resources
 
-    custom_models_js = bundle_all_models() or ""
+    bundle = bundle_for_objs_and_resources(None, resources)
 
-    nb_js = _loading_js(resources, element_id, custom_models_js, load_timeout, register_mime=True)
-    jl_js = _loading_js(resources, element_id, custom_models_js, load_timeout, register_mime=False)
+    nb_js = _loading_js(bundle, element_id, load_timeout, register_mime=True)
+    jl_js = _loading_js(bundle, element_id, load_timeout, register_mime=False)
 
     if not hide_banner:
         publish_display_data({'text/html': html})
     publish_display_data({
         JS_MIME_TYPE   : nb_js,
-        LOAD_MIME_TYPE : jl_js
+        LOAD_MIME_TYPE : jl_js,
     })
 
 def publish_display_data(*args, **kw):
@@ -531,18 +527,15 @@ _HOOKS = {}
 
 _NOTEBOOK_LOADED = None
 
-def _loading_js(resources, element_id, custom_models_js, load_timeout=5000, register_mime=True):
+def _loading_js(bundle, element_id, load_timeout=5000, register_mime=True):
     '''
 
     '''
     from ..core.templates import AUTOLOAD_NB_JS
 
     return AUTOLOAD_NB_JS.render(
+        bundle    = bundle,
         elementid = element_id,
-        js_urls   = resources.js_files,
-        css_urls  = resources.css_files,
-        js_raw    = resources.js_raw + [custom_models_js],
-        css_raw   = resources.css_raw_str,
         force     = True,
         timeout   = load_timeout,
         register_mime = register_mime
