@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -11,9 +11,7 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
@@ -23,31 +21,47 @@ log = logging.getLogger(__name__)
 # Standard library imports
 import warnings
 
-# External imports
-from six import string_types
-
 # Bokeh imports
 from ..core.enums import Location, OutputBackend, ResetPolicy
-from ..core.properties import Bool, Dict, Enum, Include, Instance, Int, List, Override, String, Float
-from ..core.property_mixins import LineProps, FillProps
+from ..core.properties import (
+    Bool,
+    Dict,
+    Enum,
+    Float,
+    Include,
+    Instance,
+    Int,
+    List,
+    Override,
+    String,
+)
+from ..core.property_mixins import ScalarFillProps, ScalarLineProps
 from ..core.query import find
 from ..core.validation import error, warning
-from ..core.validation.errors import BAD_EXTRA_RANGE_NAME, REQUIRED_RANGE, REQUIRED_SCALE, INCOMPATIBLE_SCALE_AND_RANGE
-from ..core.validation.warnings import MISSING_RENDERERS, FIXED_SIZING_MODE, FIXED_WIDTH_POLICY, FIXED_HEIGHT_POLICY
+from ..core.validation.errors import (
+    BAD_EXTRA_RANGE_NAME,
+    INCOMPATIBLE_SCALE_AND_RANGE,
+    REQUIRED_RANGE,
+    REQUIRED_SCALE,
+)
+from ..core.validation.warnings import (
+    FIXED_HEIGHT_POLICY,
+    FIXED_SIZING_MODE,
+    FIXED_WIDTH_POLICY,
+    MISSING_RENDERERS,
+)
 from ..model import Model, collect_filtered_models
-from ..util.deprecation import deprecated
 from ..util.string import nice_join
-
-from .annotations import Legend, Title
+from .annotations import Annotation, Legend, Title
 from .axes import Axis
 from .glyphs import Glyph
 from .grids import Grid
 from .layouts import LayoutDOM
-from .ranges import Range, FactorRange, DataRange1d, Range1d
+from .ranges import DataRange1d, FactorRange, Range, Range1d
 from .renderers import GlyphRenderer, Renderer, TileRenderer
-from .scales import Scale, CategoricalScale, LinearScale, LogScale
-from .sources import DataSource, ColumnDataSource
-from .tools import Tool, Toolbar, HoverTool
+from .scales import CategoricalScale, LinearScale, LogScale, Scale
+from .sources import ColumnDataSource, DataSource
+from .tools import HoverTool, Tool, Toolbar
 
 #-----------------------------------------------------------------------------
 # Globals and constants
@@ -363,7 +377,7 @@ class Plot(LayoutDOM):
 
     @warning(MISSING_RENDERERS)
     def _check_missing_renderers(self):
-        if len(self.renderers) == 0:
+        if len(self.renderers) == 0 and len([x for x in self.center if isinstance(x, Annotation)]) == 0:
             return str(self)
 
     @error(BAD_EXTRA_RANGE_NAME)
@@ -438,7 +452,7 @@ class Plot(LayoutDOM):
     will be rotated.
     """)
 
-    outline_props = Include(LineProps, help="""
+    outline_props = Include(ScalarLineProps, help="""
     The %s for the plot border outline.
     """)
 
@@ -559,13 +573,13 @@ class Plot(LayoutDOM):
 
     """)
 
-    background_props = Include(FillProps, help="""
+    background_props = Include(ScalarFillProps, help="""
     The %s for the plot background style.
     """)
 
     background_fill_color = Override(default='#ffffff')
 
-    border_props = Include(FillProps, help="""
+    border_props = Include(ScalarFillProps, help="""
     The %s for the plot border style.
     """)
 
@@ -617,23 +631,6 @@ class Plot(LayoutDOM):
     it will override ``min_border``.
     """)
 
-
-    @property
-    def h_symmetry(self):
-        deprecated("h_symmetry has been non-functional since before Bokeh 1.0 and will be removed at Bokeh 2.0")
-
-    @h_symmetry.setter
-    def h_symmetry(self, _):
-        deprecated("h_symmetry has been non-functional since before Bokeh 1.0 and will be removed at Bokeh 2.0")
-
-    @property
-    def v_symmetry(self):
-        deprecated("v_symmetry has been non-functional since before Bokeh 1.0 and will be removed at Bokeh 2.0")
-
-    @v_symmetry.setter
-    def v_symmetry(self, _):
-        deprecated("v_symmetry has been non-functional since before Bokeh 1.0 and will be removed at Bokeh 2.0")
-
     lod_factor = Int(10, help="""
     Decimation factor to use when applying level-of-detail decimation.
     """)
@@ -765,7 +762,7 @@ class _legend_attr_splat(_list_attr_splat):
     def __setattr__(self, attr, value):
         if not len(self):
             warnings.warn(_LEGEND_EMPTY_WARNING % attr)
-        return super(_legend_attr_splat, self).__setattr__(attr, value)
+        return super().__setattr__(attr, value)
 
 def _select_helper(args, kwargs):
     """ Allow flexible selector syntax.
@@ -787,7 +784,7 @@ def _select_helper(args, kwargs):
         arg = args[0]
         if isinstance(arg, dict):
             selector = arg
-        elif isinstance(arg, string_types):
+        elif isinstance(arg, str):
             selector = dict(name=arg)
         elif isinstance(arg, type) and issubclass(arg, Model):
             selector = {"type": arg}
