@@ -121,6 +121,12 @@ class SessionHandler(AuthMixin, RequestHandler):
 
         return session
 
+    # NOTE: The methods below exist on both AuthMixin and RequestHandler. This
+    # makes it explicit which of the versions is intended to be called.
+    get_login_url = AuthMixin.get_login_url
+    get_current_user = AuthMixin.get_current_user
+    prepare = AuthMixin.prepare
+
 #-----------------------------------------------------------------------------
 # Private API
 #-----------------------------------------------------------------------------
